@@ -11,7 +11,7 @@ likelihood_t_DD<-function(phylo,data,par,model=c("DDlin","DDexp")){
 	else if(model=="DDexp"){
 		try(V<-.vcv.rescale.DDexp(phylo,sig2,rate))
 	}
-	if(class(V)=="try-error"){return(Inf)}
+	if(inherits(V, "try-error")){return(Inf)}
 	if(any(is.na(V))){
 		return(Inf)
 	} else{
@@ -19,7 +19,7 @@ likelihood_t_DD<-function(phylo,data,par,model=c("DDlin","DDexp")){
   	options(show.error.messages=FALSE)
 	IV=try(solve(V))
   	options(show.error.messages=op)
-  if(class(IV)=="try-error"){
+  if(inherits(IV, "try-error")){
     IV=corpcor::pseudoinverse(V)
   	if(max(IV)==0){return(Inf)}
   }
@@ -35,4 +35,4 @@ likelihood_t_DD<-function(phylo,data,par,model=c("DDlin","DDexp")){
     if(is.na(log_final_lik) | is.infinite(log_final_lik)){log_final_lik=-1000000} #minus here because after we change the sign for minimizing the loglik
     return(as.numeric(-log_final_lik)) 
 	}
-}
\ No newline at end of file
+}
